==> zio-aws-cloud9_2.13-5.17.102.7-sources.jar: zio/aws/cloud9/model/package.scala <==
package zio.aws.cloud9
import zio.aws.cloud9.model.primitives.{TagKey, EnvironmentId}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.cloud9.model.primitives.MaxResults.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AutomaticStopTimeMinutes extends Subtype[Int]
    type AutomaticStopTimeMinutes =
      zio.aws.cloud9.model.primitives.AutomaticStopTimeMinutes.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.cloud9.model.primitives.ClientRequestToken.Type
    object EnvironmentArn extends Subtype[String]
    type EnvironmentArn = zio.aws.cloud9.model.primitives.EnvironmentArn.Type
    object EnvironmentDescription extends Subtype[String]
    type EnvironmentDescription =
      zio.aws.cloud9.model.primitives.EnvironmentDescription.Type
    object EnvironmentId extends Subtype[String]
    type EnvironmentId = zio.aws.cloud9.model.primitives.EnvironmentId.Type
    object EnvironmentName extends Subtype[String]
    type EnvironmentName = zio.aws.cloud9.model.primitives.EnvironmentName.Type
    object ImageId extends Subtype[String]
    type ImageId = zio.aws.cloud9.model.primitives.ImageId.Type
    object InstanceType extends Subtype[String]
    type InstanceType = zio.aws.cloud9.model.primitives.InstanceType.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.cloud9.model.primitives.MaxResults.Type
    object NullableBoolean extends Subtype[Boolean]
    type NullableBoolean = zio.aws.cloud9.model.primitives.NullableBoolean.Type
    object SubnetId extends Subtype[String]
    type SubnetId = zio.aws.cloud9.model.primitives.SubnetId.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.cloud9.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.cloud9.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.cloud9.model.primitives.Timestamp.Type
    object UserArn extends Subtype[String]
    type UserArn = zio.aws.cloud9.model.primitives.UserArn.Type
  }
  type BoundedEnvironmentIdList = List[EnvironmentId]
  type EnvironmentIdList = List[EnvironmentId]
  type EnvironmentList = List[zio.aws.cloud9.model.Environment]
  type EnvironmentMembersList = List[zio.aws.cloud9.model.EnvironmentMember]
  type PermissionsList = List[zio.aws.cloud9.model.Permissions]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.cloud9.model.Tag]
}

==> zio-aws-cloud9_2.13-5.17.211.1-sources.jar: zio/aws/cloud9/model/package.scala <==
package zio.aws.cloud9
import zio.aws.cloud9.model.primitives.{TagKey, EnvironmentId}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.cloud9.model.primitives.MaxResults.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AutomaticStopTimeMinutes extends Subtype[Int]
    type AutomaticStopTimeMinutes =
      zio.aws.cloud9.model.primitives.AutomaticStopTimeMinutes.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.cloud9.model.primitives.ClientRequestToken.Type
    object EnvironmentArn extends Subtype[String]
    type EnvironmentArn = zio.aws.cloud9.model.primitives.EnvironmentArn.Type
    object EnvironmentDescription extends Subtype[String]
    type EnvironmentDescription =
      zio.aws.cloud9.model.primitives.EnvironmentDescription.Type
    object EnvironmentId extends Subtype[String]
    type EnvironmentId = zio.aws.cloud9.model.primitives.EnvironmentId.Type
    object EnvironmentName extends Subtype[String]
    type EnvironmentName = zio.aws.cloud9.model.primitives.EnvironmentName.Type
    object ImageId extends Subtype[String]
    type ImageId = zio.aws.cloud9.model.primitives.ImageId.Type
    object InstanceType extends Subtype[String]
    type InstanceType = zio.aws.cloud9.model.primitives.InstanceType.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.cloud9.model.primitives.MaxResults.Type
    type NullableBoolean = Boolean
    object SubnetId extends Subtype[String]
    type SubnetId = zio.aws.cloud9.model.primitives.SubnetId.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.cloud9.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.cloud9.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.cloud9.model.primitives.Timestamp.Type
    object UserArn extends Subtype[String]
    type UserArn = zio.aws.cloud9.model.primitives.UserArn.Type
  }
  type BoundedEnvironmentIdList = List[EnvironmentId]
  type EnvironmentIdList = List[EnvironmentId]
  type EnvironmentList = List[zio.aws.cloud9.model.Environment]
  type EnvironmentMembersList = List[zio.aws.cloud9.model.EnvironmentMember]
  type PermissionsList = List[zio.aws.cloud9.model.Permissions]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.cloud9.model.Tag]
}
